Enum caesar_core::shared::JsonPacket
source · pub enum JsonPacket {
Join {
id: String,
},
Create {
id: Option<String>,
},
Leave,
}Expand description
Represents a packet that is sent over a websocket connection.
This enum is used to represent different types of packets that can be sent over a websocket connection.
Variants
Join
A packet to join a room.
This variant is used to request to join a room. The id field is used to specify the room id.
Create
A packet to create a new room.
This variant is used to request to create a new room. The id field is used to specify the room id, which can be optional.
Leave
A packet to leave a room.
This variant is used to request to leave a room.